==> fengoffice_1.7.5.zip: fengoffice/language/zh_cn/calendar.php <==
<?php return array(
	'CAL_QUERY_GETEVENT_ERROR' => '数据库错误：通过ID获取事件失败',
	'CAL_QUERY_SETEVENT_ERROR' => '数据库错误: 无法设置事件数据',
	'CAL_SUBM_LOGOUT' => '退出',
	'CAL_SUBM_LOGIN' => '登录',
	'CAL_SUBM_ADMINPAGE' => '管理页',
	'CAL_SUBM_SEARCH' => '搜索',
	'CAL_SUBM_BACK_CALENDAR' => '回到日历',
	'CAL_SUBM_VIEW_TODAY' => '查看今天的事件',
	'CAL_SUBM_ADD' => '添加今天事件',
	'CAL_MENU_BACK_CALENDAR' => '返回到日历',
	'CAL_MENU_NEWEVENT' => '新事件',
	'CAL_MENU_BACK_EVENTS' => '返回到事件',
	'CAL_MENU_GO' => '转到',
	'CAL_MENU_TODAY' => '今天',
	'CAL_NO_READ_PERMISSION' => '你没有查看事件的权限。',
	'CAL_NO_WRITE_PERMISSION' => '你没有添加或编辑事件的权限。',
	'CAL_NO_EDITOTHERS_PERMISSION' => '你没有编辑其他用户事件的权限。',
	'CAL_NO_EDITPAST_PERMISSION' => '你没有编辑过去事件的权限。',
	'CAL_NO_ACCOUNTS' => '日历没有许可的帐户，只有管理员可以登录。',
	'CAL_NO_MODIFY' => '不能编辑',
	'CAL_NO_ANYTHING' => '你没有权限在本页面作任何事。',
	'CAL_NO_WRITE' => '你没有权限创建新事件。',
	'CAL_MONDAY' => '周一',
	'CAL_TUESDAY' => '周二',
	'CAL_WEDNESDAY' => '周三',
	'CAL_THURSDAY' => '周四',
	'CAL_FRIDAY' => '周五',
	'CAL_SATURDAY' => '周六',
	'CAL_SUNDAY' => '周日',
	'CAL_SHORT_MONDAY' => '一',
	'CAL_SHORT_TUESDAY' => '二',
	'CAL_SHORT_WEDNESDAY' => '三',
	'CAL_SHORT_THURSDAY' => '四',
	'CAL_SHORT_FRIDAY' => '五',
	'CAL_SHORT_SATURDAY' => '六',
	'CAL_SHORT_SUNDAY' => '日',
	'CAL_JANUARY' => '一月',
	'CAL_FEBRUARY' => '二月',
	'CAL_MARCH' => '三月',
	'CAL_APRIL' => '四月',
	'CAL_MAY' => '五月',
	'CAL_JUNE' => '六月',
	'CAL_JULY' => '七月',
	'CAL_AUGUST' => '八月',
	'CAL_SEPTEMBER' => '九月',
	'CAL_OCTOBER' => '十月',
	'CAL_NOVEMBER' => '十一月',
	'CAL_DECEMBER' => '十二月',
	'CAL_MORE_TIME_OPTIONS' => '更多时间选项',
	'CAL_REPEAT' => '重复',
	'CAL_EVERY' => '每',
	'CAL_REPEAT_FOREVER' => '永远重复',
	'CAL_REPEAT_UNTIL' => '重复直到',
	'CAL_TIMES' => '时间',
	'CAL_HOLIDAY_EXPLAIN' => '这个事件将在',
	'CAL_DURING' => '在',
	'CAL_EVERY_YEAR' => '每年',
	'CAL_HOLIDAY_EXTRAOPTION' => '或者，由于这个日期在本月的最后一周，选择此项来使这个日期落在最后一周的',
	'CAL_IN' => '在',
	'CAL_PRIVATE_EVENT_EXPLAIN' => '这是一个私有事件',
	'CAL_SUBMIT_ITEM' => '提交条目',
	'CAL_MINUTES' => '分钟',
	'CAL_MINUTES_SHORT' => '分',
	'CAL_TIME_AND_DURATION' => '日期、时间和时长',
	'CAL_REPEATING_EVENT' => '重复事件',
	'CAL_EXTRA_OPTIONS' => '扩展选项',
	'CAL_ONLY_TODAY' => '只在今天',
	'CAL_DAILY_EVENT' => '每天重复',
	'CAL_WEEKLY_EVENT' => '每周重复',
	'CAL_MONTHLY_EVENT' => '每月重复',
	'CAL_YEARLY_EVENT' => '每年重复',
	'CAL_HOLIDAY_EVENT' => '假日重复',
	'CAL_UNKNOWN_TIME' => '未知的开始时间',
	'CAL_ADDING_TO' => '添加到',
	'CAL_ANON_ALIAS' => '别名',
	'CAL_EVENT_TYPE' => '事件类型',
	'CAL_DESCRIPTION' => '描述',
	'CAL_DURATION' => '时长',
	'CAL_DATE' => '日期',
	'CAL_NO_EVENTS_FOUND' => '没有事件',
	'CAL_NO_SUBJECT' => '没有主题',
	'CAL_PRIVATE_EVENT' => '私有事件',
	'CAL_DELETE' => '删除',
	'CAL_MODIFY' => '编辑',
	'CAL_NOT_SPECIFIED' => '没有被指定',
	'CAL_FULL_DAY' => '整天',
	'CAL_HACKING_ATTEMPT' => '黑客攻击－IP地址已被记录',
	'CAL_TIME' => '时间',
	'CAL_HOURS' => '小时',
	'CAL_HOUR' => '小时',
	'CAL_ANONYMOUS' => '匿名',
	'CAL_SELECT_TIME' => '选择开始时间',
	'event invitations' => '被邀请者',
	'event invitations desc' => '邀请所选人员参与此事件',
	'send new event notification' => '发送邮件通知',
	'new event notification' => '新事件已经被添加',
	'change event notification' => '事件已经被改变',
	'deleted event notification' => '事件已经被删除',
	'attendance' => '你将参加吗?',
	'confirm attendance' => '确认出席',
	'maybe' => '可能参加',
	'decide later' => '稍后决定',
	'view event' => '查看事件',
	'new event created' => '新事件已经创建',
	'event changed' => '事件已被更改',
	'event deleted' => '事件已被删除',
	'calendar of' => '{0}的日历',
	'all users' => '所有用户',
	'error delete event' => '删除事件错误',
	'days' => '天',
	'weeks' => '周',
	'months' => '月',
	'years' => '年',
	'invitations' => '邀请',
	'pending response' => '等待回应',
	'participate' => '将出席',
	'no invitations to this event' => '没有邀请被发送到这个事件',
	'duration must be at least 15 minutes' => '时长须至少15分钟',
	'event dnx' => '请求的事件不存在',
	'no subject' => '无主题',
	'success import events' => '{0}个事件被导入.',
	'no events to import' => '没有事件导入',
	'import events from file' => '从文件中导入事件',
	'file should be in icalendar format' => '文件必须是iCalendar 格式',
	'export calendar' => '日历导出',
	'range of events' => '事件范围',
	'from date' => '从',
	'to date' => '到',
	'success export calendar' => '{0} 事件已被导出。',
	'calendar name desc' => '导出的日历名称',
	'calendar will be exported in icalendar format' => '日历将被导出为iCalendar格式。',
	'view date title' => 'Y/m/d',
	'event invitation response' => '事件邀请回复',
	'user will attend to event' => '{0}将参加此事件',
	'user will not attend to event' => '{0}将<strong>不</strong>参加此事件',
	'accept invitation' => '接受邀请',
	'reject invitation' => '拒绝邀请',
	'invitation accepted' => '邀请被接受',
	'invitation rejected' => '邀请被拒绝',
	'import events from third party software' => '从第三方软件导入事件',
	'accept or reject invitation help, click on one of the links below' => '要接受或拒绝邀请，点击下面链接之一。',
	'copy this url in your calendar client software' => '为从此日历中导入事件，请将此URL地址拷贝到您的日历客户端软件中。',
	'subws' => '子工作区',
	'check to include sub ws' => '选中此项以包含子工作区到URL地址中',
	'week short' => '周',
	'week number x' => '第{0}周',
	'also confirmed attendance' => '亦是确认出席',
	'awaiting confirmation' => '待确认',
	'rejected invitation' => '不出席',
	'who' => '谁',
	'what' => '什么',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/zh_cn/calendar.php <==
<?php return array(
	'CAL_QUERY_GETEVENT_ERROR' => '数据库错误：通过ID获取事件失败',
	'CAL_QUERY_SETEVENT_ERROR' => '数据库错误: 无法设置事件数据',
	'CAL_SUBM_LOGOUT' => '退出',
	'CAL_SUBM_LOGIN' => '登录',
	'CAL_SUBM_ADMINPAGE' => '管理页',
	'CAL_SUBM_SEARCH' => '搜索',
	'CAL_SUBM_BACK_CALENDAR' => '回到日历',
	'CAL_SUBM_VIEW_TODAY' => '显示今天的事件',
	'CAL_SUBM_ADD' => '添加今天事件',
	'CAL_MENU_BACK_CALENDAR' => '返回到日历',
	'CAL_MENU_NEWEVENT' => '新事件',
	'CAL_MENU_BACK_EVENTS' => '返回到事件',
	'CAL_MENU_GO' => '去',
	'CAL_MENU_TODAY' => '今天',
	'CAL_NO_READ_PERMISSION' => '你没有显示事件的权限。',
	'CAL_NO_WRITE_PERMISSION' => '你没有添加或编辑事件的权限。',
	'CAL_NO_EDITOTHERS_PERMISSION' => '你没有编辑其他用户事件的权限。',
	'CAL_NO_EDITPAST_PERMISSION' => '你没有编辑过去事件的权限。',
	'CAL_NO_ACCOUNTS' => '日历没有许可的帐户，只有管理员可以登录。',
	'CAL_NO_MODIFY' => '不能编辑',
	'CAL_NO_ANYTHING' => '你没有权限在本页面作任何事。',
	'CAL_NO_WRITE' => '你没有权限创建新事件。',
	'CAL_MONDAY' => '周一',
	'CAL_TUESDAY' => '周二',
	'CAL_WEDNESDAY' => '周三',
	'CAL_THURSDAY' => '周四',
	'CAL_FRIDAY' => '周五',
	'CAL_SATURDAY' => '周六',
	'CAL_SUNDAY' => '周日',
	'CAL_SHORT_MONDAY' => '一',
	'CAL_SHORT_TUESDAY' => '二',
	'CAL_SHORT_WEDNESDAY' => '三',
	'CAL_SHORT_THURSDAY' => '四',
	'CAL_SHORT_FRIDAY' => '五',
	'CAL_SHORT_SATURDAY' => '六',
	'CAL_SHORT_SUNDAY' => '日',
	'CAL_JANUARY' => '一月',
	'CAL_FEBRUARY' => '二月',
	'CAL_MARCH' => '三月',
	'CAL_APRIL' => '四月',
	'CAL_MAY' => '五月',
	'CAL_JUNE' => '六月',
	'CAL_JULY' => '七月',
	'CAL_AUGUST' => '八月',
	'CAL_SEPTEMBER' => '九月',
	'CAL_OCTOBER' => '十月',
	'CAL_NOVEMBER' => '十一月',
	'CAL_DECEMBER' => '十二月',
	'CAL_MORE_TIME_OPTIONS' => '更多时间选项',
	'CAL_REPEAT' => '重复',
	'CAL_EVERY' => '每',
	'CAL_REPEAT_FOREVER' => '永远重复',
	'CAL_REPEAT_UNTIL' => '重复直到',
	'CAL_TIMES' => '时间',
	'CAL_HOLIDAY_EXPLAIN' => '这个事件将在',
	'CAL_DURING' => '在',
	'CAL_EVERY_YEAR' => '每年里的',
	'CAL_HOLIDAY_EXTRAOPTION' => '或者，由于这个日期在本月的最后一周，选择此项来使这个日期落在最后一周的',
	'CAL_IN' => '在',
	'CAL_PRIVATE_EVENT_EXPLAIN' => '这是一个私有的事件',
	'CAL_SUBMIT_ITEM' => '提交条目',
	'CAL_MINUTES' => '分钟',
	'CAL_MINUTES_SHORT' => '分',
	'CAL_TIME_AND_DURATION' => '日期、时间和时长',
	'CAL_REPEATING_EVENT' => '重复时间',
	'CAL_EXTRA_OPTIONS' => '扩展选项',
	'CAL_ONLY_TODAY' => '只在今天',
	'CAL_DAILY_EVENT' => '每天重复',
	'CAL_WEEKLY_EVENT' => '每周重复',
	'CAL_MONTHLY_EVENT' => '每月重复',
	'CAL_YEARLY_EVENT' => '每年重复',
	'CAL_HOLIDAY_EVENT' => '假日重复',
	'CAL_UNKNOWN_TIME' => '未知的开始时间',
	'CAL_ADDING_TO' => '添加到',
	'CAL_ANON_ALIAS' => '别名',
	'CAL_EVENT_TYPE' => '事件类型',
	'CAL_DESCRIPTION' => '描述',
	'CAL_DURATION' => '时长',
	'CAL_DATE' => '日期',
	'CAL_NO_EVENTS_FOUND' => '没有发现事件',
	'CAL_NO_SUBJECT' => '没有主题',
	'CAL_PRIVATE_EVENT' => '私有事件',
	'CAL_DELETE' => '删除',
	'CAL_MODIFY' => '编辑',
	'CAL_NOT_SPECIFIED' => '没有被指定',
	'CAL_FULL_DAY' => '整天',
	'CAL_HACKING_ATTEMPT' => '黑客攻击－IP地址已经被记录',
	'CAL_TIME' => '时间',
	'CAL_HOURS' => '小时',
	'CAL_HOUR' => '小时',
	'CAL_ANONYMOUS' => '匿名',
	'CAL_SELECT_TIME' => '选择开始时间',
	'event invitations' => '事件邀请',
	'event invitations desc' => '邀请所选人员参与此事件',
	'send new event notification' => '发送邮件通知',
	'new event notification' => '新事件已经被添加',
	'change event notification' => '事件已经被改变',
	'deleted event notification' => '事件已经被删除',
	'attendance' => '你想参与么?',
	'confirm attendance' => '确认出席',
	'maybe' => '可能',
	'decide later' => '决定推迟',
	'view event' => '显示事件',
	'new event created' => '新事件已经创建',
	'event changed' => '事件已经改变',
	'event deleted' => '事件已经删除',
	'calendar of' => '{0}的日历',
	'all users' => '所有用户',
	'error delete event' => '删除事件错误',
	'days' => '天',
	'weeks' => '周',
	'months' => '月',
	'years' => '年',
	'invitations' => '邀请',
	'pending response' => '等待相应',
	'participate' => '将出席',
	'no invitations to this event' => '没有被送到这个事件的邀请',
	'duration must be at least 15 minutes' => '时长至少15分钟',
	'event dnx' => '请求的事件不存在',
	'no subject' => '无主题',
	'success import events' => '{0} 事件被导入.',
	'no events to import' => '没有事件导入',
	'import events from file' => '从文件中导入事件',
	'file should be in icalendar format' => '文件必须是iCalendar 格式',
	'export calendar' => '日历导出',
	'range of events' => '事件范围',
	'from date' => '从',
	'to date' => '到',
	'success export calendar' => '{0} 事件已被导出。',
	'calendar name desc' => '导出的日历名称',
	'calendar will be exported in icalendar format' => '日历将被导出为iCalendar格式。',
	'view date title' => 'Y/m/d',
	'event invitation response' => '事件邀请回复',
	'user will attend to event' => '{0}将参加此次事件',
	'user will not attend to event' => '{0}将<strong>不</strong>参加此次事件',
	'accept invitation' => '接受邀请',
	'reject invitation' => '拒绝邀请',
	'invitation accepted' => '邀请被接受',
	'invitation rejected' => '邀请被拒绝',
	'import events from third party software' => '从第三方软件导入事件',
	'accept or reject invitation help, click on one of the links below' => '要接受或拒绝邀请，点击下面链接之一。',
	'copy this url in your calendar client software' => '为从此日历中导入事件，请将此URL地址拷贝到您的日历客户端软件中。',
	'subws' => '子工作区',
	'check to include sub ws' => '选中此项以包含子工作区到URL地址中',
	'week short' => '周',
	'week number x' => '第{0}周',
); ?>
